@@ -20,7 +20,13 @@ RayleighEllipticity = namedtuple(
 
 class Ellipticity(Base):
     def __init__(
-        self, thickness, velocity_p, velocity_s, density, algorithm="dunkin", dc=0.005,
+        self,
+        thickness,
+        velocity_p,
+        velocity_s,
+        density,
+        algorithm="dunkin",
+        dc=0.005,
     ):
         """
         Ellipticity class (only Rayleigh-wave).
@@ -58,7 +64,7 @@ class Ellipticity(Base):
 
         Returns
         -------
-        namedtuple
+        :class:`disba.RayleighEllipticity`
             Rayleigh-wave ellipticity as a namedtuple (period, ellipticity, mode).
 
         """
